﻿using System.Collections.ObjectModel;
using System.ComponentModel;

namespace XamOutlookBarDataBinding
{
    public class ViewModel : INotifyPropertyChanged
    {
        private ObservableCollection<Group> _groups;
        public ObservableCollection<Group> Groups
        {
            get { return _groups; }
            set
            {
                _groups = value;
                OnPropertyChanged("Groups");
            }
        }

        public ViewModel()
        {
            Groups = GenerateGroups();
        }

        private ObservableCollection<Group> GenerateGroups()
        {
            ObservableCollection<Group> groups = new ObservableCollection<Group>();

            //create the mail group with menu items
            var mailGroup = new Group() { Title = "Mail",
                LargeImagePath = @"/XamOutlookBarDataBinding;component/Images/Mail32.png", 
                SmallImagePath = @"/XamOutlookBarDataBinding;component/Images/Mail16.png" };
            var rootMailItem = new MenuItem() { Title = "Personal Folders", IsExpanded = true };
            rootMailItem.Children.Add(new MenuItem() { Title = "Inbox", ImagePath = @"/XamOutlookBarDataBinding;component/Images/InboxFolder16.png" });
            rootMailItem.Children.Add(new MenuItem() { Title = "Drafts", ImagePath = @"/XamOutlookBarDataBinding;component/Images/DraftsFolder16.png" });
            rootMailItem.Children.Add(new MenuItem() { Title = "Sent Items", ImagePath = @"/XamOutlookBarDataBinding;component/Images/SentFolder16.png" });
            rootMailItem.Children.Add(new MenuItem() { Title = "Deleted Items", ImagePath = @"/XamOutlookBarDataBinding;component/Images/DeletedFolder16.png" });
            mailGroup.Items.Add(rootMailItem);

            //create the contacts group with menu items
            var contactsGroup = new Group() { Title = "Contacts", 
                LargeImagePath = @"/XamOutlookBarDataBinding;component/Images/Contact32.png", 
                SmallImagePath = @"/XamOutlookBarDataBinding;component/Images/Contact16.png" };
            var rootContactItem = new MenuItem() { Title = "My Contacts", IsExpanded = true };
            rootContactItem.Children.Add(new MenuItem() { Title = "Suggested Contacts", ImagePath = @"/XamOutlookBarDataBinding;component/Images/Contact16.png" });
            rootContactItem.Children.Add(new MenuItem() { Title = "Contacts" , ImagePath = @"/XamOutlookBarDataBinding;component/Images/Contact16.png" });
            contactsGroup.Items.Add(rootContactItem);

            groups.Add(mailGroup);
            groups.Add(contactsGroup);

            return groups;
        }

        public event PropertyChangedEventHandler PropertyChanged;
        protected void OnPropertyChanged(string propertyname)
        {
            var handler = PropertyChanged;
            if (handler != null)
                handler(this, new PropertyChangedEventArgs(propertyname));
        }
    }
}
